import * as i0 from '@angular/core';
import { Injectable, Inject, EventEmitter, Directive, Output, HostListener, Component, Input, ViewChild, NgModule } from '@angular/core';
import * as i2 from '@angular/forms';
import { NG_VALUE_ACCESSOR, FormsModule, ReactiveFormsModule } from '@angular/forms';
import * as i2$1 from '@angular/common';
import { DOCUMENT, CommonModule } from '@angular/common';
import { skip, distinctUntilChanged, debounceTime } from 'rxjs/operators';

var ToolbarItemType;
(function (ToolbarItemType) {
    ToolbarItemType[ToolbarItemType["Separator"] = 0] = "Separator";
    ToolbarItemType[ToolbarItemType["Button"] = 1] = "Button";
    ToolbarItemType[ToolbarItemType["Select"] = 2] = "Select";
    ToolbarItemType[ToolbarItemType["Color"] = 3] = "Color";
    ToolbarItemType[ToolbarItemType["Input"] = 4] = "Input";
    ToolbarItemType[ToolbarItemType["Dropdown"] = 5] = "Dropdown";
})(ToolbarItemType || (ToolbarItemType = {}));

const UNDO_BUTTON = { type: ToolbarItemType.Button, command: "undo" /* ExecCommand.undo */, icon: 'fas fa-undo', title: 'undo' };
const REDO_BUTTON = { type: ToolbarItemType.Button, command: "redo" /* ExecCommand.redo */, icon: 'fas fa-redo', title: 'redo' };
const REMOVE_FORMAT_BUTTON = { type: ToolbarItemType.Button, command: "removeFormat" /* ExecCommand.removeFormat */, icon: 'fas fa-remove-format', title: 'remove format' };
const SEPARATOR = { type: ToolbarItemType.Separator };
const BOLD_BUTTON = { type: ToolbarItemType.Button, command: "bold" /* ExecCommand.bold */, icon: 'fas fa-bold', title: 'bold' };
const ITALIC_BUTTON = { type: ToolbarItemType.Button, command: "italic" /* ExecCommand.italic */, icon: 'fas fa-italic', title: 'italic' };
const UNDERLINE_BUTTON = { type: ToolbarItemType.Button, command: "underline" /* ExecCommand.underline */, icon: 'fas fa-underline', title: 'underline' };
const STRIKE_THROUGH_BUTTON = { type: ToolbarItemType.Button, command: "strikeThrough" /* ExecCommand.strikeThrough */, icon: 'fas fa-strikethrough', title: 'strikethrough' };
const JUSTIFY_LEFT_BUTTON = { type: ToolbarItemType.Button, command: "justifyLeft" /* ExecCommand.justifyLeft */, icon: 'fas fa-align-left', title: 'align left' };
const JUSTIFY_CENTER_BUTTON = { type: ToolbarItemType.Button, command: "justifyCenter" /* ExecCommand.justifyCenter */, icon: 'fas fa-align-center', title: 'align center' };
const JUSTIFY_RIGHT_BUTTON = { type: ToolbarItemType.Button, command: "justifyRight" /* ExecCommand.justifyRight */, icon: 'fas fa-align-right', title: 'align right' };
const JUSTIFY_FULL_BUTTON = { type: ToolbarItemType.Button, command: "justifyFull" /* ExecCommand.justifyFull */, icon: 'fas fa-align-justify', title: 'align justify' };
const ORDERED_LIST_BUTTON = { type: ToolbarItemType.Button, command: "insertOrderedList" /* ExecCommand.insertOrderedList */, icon: 'fas fa-list-ol', title: 'ordered list' };
const UNORDERED_LIST_BUTTON = { type: ToolbarItemType.Button, command: "insertUnorderedList" /* ExecCommand.insertUnorderedList */, icon: 'fas fa-list-ul', title: 'unordered list' };
const INDENT_BUTTON = { type: ToolbarItemType.Button, command: "indent" /* ExecCommand.indent */, icon: 'fas fa-indent', title: 'indent' };
const OUTDENT_BUTTON = { type: ToolbarItemType.Button, command: "outdent" /* ExecCommand.outdent */, icon: 'fas fa-outdent', title: 'outdent' };
const SUBSCRIPT_BUTTON = { type: ToolbarItemType.Button, command: "subscript" /* ExecCommand.subscript */, icon: 'fas fa-subscript', title: 'subscript' };
const SUPERSCRIPT_BUTTON = { type: ToolbarItemType.Button, command: "superscript" /* ExecCommand.superscript */, icon: 'fas fa-superscript', title: 'superscript' };
const FONT_SIZE_SELECT = {
    type: ToolbarItemType.Select, command: "fontSize" /* ExecCommand.fontSize */, title: 'font size', items: [
        { value: 1, label: '1' },
        { value: 2, label: '2' },
        { value: 3, label: '3' },
        { value: 4, label: '4' },
        { value: 5, label: '5' },
        { value: 6, label: '6' },
        { value: 7, label: '7' },
    ]
};
const LINK_INPUT = { type: ToolbarItemType.Input, command: "createLink" /* ExecCommand.createLink */, icon: 'fas fa-link', text: 'Create link', title: 'create link', label: 'Create link' };
const UNLINK_BUTTON = { type: ToolbarItemType.Button, command: "unlink" /* ExecCommand.unlink */, icon: 'fas fa-unlink', title: 'unlink' };
const FORE_COLOR = { type: ToolbarItemType.Color, command: "foreColor" /* ExecCommand.foreColor */, icon: 'fas fa-palette', title: 'font color' };
const IMAGE_INPUT = { type: ToolbarItemType.Input, command: "insertImage" /* ExecCommand.insertImage */, icon: 'fas fa-image', text: 'Add image', title: 'add image', label: 'Create image from link' };
const CUSTOM = {
    type: ToolbarItemType.Dropdown, label: 'Custom', title: 'test custom', items: [
        { command: "insertHTML" /* ExecCommand.insertHTML */, value: '<b>This is bold<b>', label: 'Custom bold text' },
        { command: "italic" /* ExecCommand.italic */, value: null, label: 'Make Italic' },
    ]
};
const ST_BUTTONS = [
    UNDO_BUTTON,
    REDO_BUTTON,
    REMOVE_FORMAT_BUTTON,
    SEPARATOR,
    BOLD_BUTTON,
    ITALIC_BUTTON,
    UNDERLINE_BUTTON,
    STRIKE_THROUGH_BUTTON,
    SEPARATOR,
    JUSTIFY_LEFT_BUTTON,
    JUSTIFY_CENTER_BUTTON,
    JUSTIFY_RIGHT_BUTTON,
    JUSTIFY_FULL_BUTTON,
    SEPARATOR,
    ORDERED_LIST_BUTTON,
    UNORDERED_LIST_BUTTON,
    SEPARATOR,
    INDENT_BUTTON,
    OUTDENT_BUTTON,
    SEPARATOR,
    SUBSCRIPT_BUTTON,
    SUPERSCRIPT_BUTTON,
    SEPARATOR,
    FONT_SIZE_SELECT,
    LINK_INPUT,
    UNLINK_BUTTON,
    SEPARATOR,
    IMAGE_INPUT,
    FORE_COLOR,
];

class CommandService {
    constructor(document) {
        this.document = document;
    }
    isCommandWithValue(item) {
        return item.type === ToolbarItemType.Select || item.type === ToolbarItemType.Color;
    }
    isCommandWithState(item) {
        return item.type === ToolbarItemType.Button;
    }
    getQueryCommandState(buttons) {
        return buttons
            .filter(item => this.isCommandWithValue(item) || this.isCommandWithState(item))
            .reduce((acc, curr) => ({
            ...acc,
            [curr.command]: this.isCommandWithValue(curr) ?
                this.document.queryCommandValue(String(curr.command)) :
                this.document.queryCommandState(String(curr.command)),
        }), {});
    }
    execCommand(command, value) {
        this.document.execCommand(command, false, value ? String(value) : value);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: CommandService, deps: [{ token: DOCUMENT }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: CommandService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: CommandService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: Document, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }] });

class ActionDirective {
    constructor() {
        this.action = new EventEmitter();
    }
    enterDown(event) {
        this.stopEvent(event);
    }
    enterUp(event) {
        this.performAction(event);
    }
    click(event) {
        this.performAction(event);
    }
    stopEvent(event) {
        event.preventDefault();
        event.stopPropagation();
    }
    performAction(event) {
        this.stopEvent(event);
        this.action.emit(event);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: ActionDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.3.2", type: ActionDirective, selector: "[stAction]", outputs: { action: "stAction" }, host: { listeners: { "keydown.enter": "enterDown($event)", "keyup.enter": "enterUp($event)", "click": "click($event)" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: ActionDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[stAction]',
                }]
        }], propDecorators: { action: [{
                type: Output,
                args: ['stAction']
            }], enterDown: [{
                type: HostListener,
                args: ['keydown.enter', ['$event']]
            }], enterUp: [{
                type: HostListener,
                args: ['keyup.enter', ['$event']]
            }], click: [{
                type: HostListener,
                args: ['click', ['$event']]
            }] } });

class EditorButtonComponent {
    constructor() {
        this.command = new EventEmitter();
    }
    onCommand(command) {
        this.command.emit(command);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: EditorButtonComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.2", type: EditorButtonComponent, selector: "st-button", inputs: { button: "button", state: "state" }, outputs: { command: "command" }, ngImport: i0, template: "<button class=\"st-button st-toolbar-item\"\n        [title]=\"button?.title || ''\"\n        (stAction)=\"onCommand(button?.command)\"\n        [class.active]=\"state\">\n  <i [class]=\"button?.icon\"></i>\n</button>\n", styles: [".st-toolbar-item{border:0;padding:8px 14px;background-color:#fff;border-radius:5px;margin-right:1px;cursor:pointer}.st-toolbar-item:hover{background-color:#e0e0e0}.st-toolbar-item:focus{outline-color:#424242}.st-button:hover{background-color:#e0e0e0}.st-button:active{transform:scale(.98);box-shadow:1px 1px 7px 1px #e0e0e0}.st-button.active{background-color:#424242;color:#fff}\n"], dependencies: [{ kind: "directive", type: ActionDirective, selector: "[stAction]", outputs: ["stAction"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: EditorButtonComponent, decorators: [{
            type: Component,
            args: [{ selector: 'st-button', template: "<button class=\"st-button st-toolbar-item\"\n        [title]=\"button?.title || ''\"\n        (stAction)=\"onCommand(button?.command)\"\n        [class.active]=\"state\">\n  <i [class]=\"button?.icon\"></i>\n</button>\n", styles: [".st-toolbar-item{border:0;padding:8px 14px;background-color:#fff;border-radius:5px;margin-right:1px;cursor:pointer}.st-toolbar-item:hover{background-color:#e0e0e0}.st-toolbar-item:focus{outline-color:#424242}.st-button:hover{background-color:#e0e0e0}.st-button:active{transform:scale(.98);box-shadow:1px 1px 7px 1px #e0e0e0}.st-button.active{background-color:#424242;color:#fff}\n"] }]
        }], propDecorators: { button: [{
                type: Input
            }], state: [{
                type: Input
            }], command: [{
                type: Output
            }] } });

const DEBOUNCE_TIME_MS = 100;
class NgModelChangeDebouncedDirective {
    constructor(ngModel) {
        this.ngModel = ngModel;
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.stNgModelChangeDebounced = new EventEmitter();
    }
    ngOnInit() {
        this.subscription = this.ngModel.control.valueChanges.pipe(skip(1), distinctUntilChanged(), debounceTime(DEBOUNCE_TIME_MS)).subscribe((value) => this.stNgModelChangeDebounced.emit(value));
    }
    ngOnDestroy() {
        this.subscription.unsubscribe();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: NgModelChangeDebouncedDirective, deps: [{ token: i2.NgModel }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.3.2", type: NgModelChangeDebouncedDirective, selector: "[stNgModelChangeDebounced]", outputs: { stNgModelChangeDebounced: "stNgModelChangeDebounced" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: NgModelChangeDebouncedDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[stNgModelChangeDebounced]',
                }]
        }], ctorParameters: () => [{ type: i2.NgModel }], propDecorators: { stNgModelChangeDebounced: [{
                type: Output
            }] } });

const DEFAULT_COLOR = '#000000';
class EditorColorPickerComponent {
    constructor() {
        this.command = new EventEmitter();
    }
    onCommand(command, value) {
        this.command.emit({ command, value });
    }
    rgbStringToHex(rgb) {
        const match = String(rgb).match(/rgba?\((\d{1,3}), ?(\d{1,3}), ?(\d{1,3})\)?(?:, ?(\d(?:\.\d?))\))?/);
        return !match ? DEFAULT_COLOR : '#' + [match[1], match[2], match[3]].map(x => {
            const hex = Number(x).toString(16);
            return hex.length === 1 ? '0' + hex : hex;
        }).join('');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: EditorColorPickerComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.2", type: EditorColorPickerComponent, selector: "st-color-picker", inputs: { button: "button", state: "state" }, outputs: { command: "command" }, ngImport: i0, template: "<button class=\"st-button st-toolbar-item\" [title]=\"button?.title || ''\" (stAction)=\"colorPicker.showPicker()\">\n  {{rgbStringToHex(state)}}\n  <input #colorPicker class=\"st-color-picker\" type=\"color\" [ngModel]=\"rgbStringToHex(state)\" tabindex=\"-1\"\n         (stNgModelChangeDebounced)=\"onCommand(button?.command, $event)\">\n  <i [class]=\"button?.icon\" [style.color]=\"state\"></i>\n</button>\n", styles: [".st-toolbar-item{border:0;padding:8px 14px;background-color:#fff;border-radius:5px;margin-right:1px;cursor:pointer}.st-toolbar-item:hover{background-color:#e0e0e0}.st-toolbar-item:focus{outline-color:#424242}.st-button:hover{background-color:#e0e0e0}.st-button:active{transform:scale(.98);box-shadow:1px 1px 7px 1px #e0e0e0}.st-button.active{background-color:#424242;color:#fff}.st-color-picker{width:0;height:0;border:0;padding:0;margin:0;pointer-events:none}\n"], dependencies: [{ kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: ActionDirective, selector: "[stAction]", outputs: ["stAction"] }, { kind: "directive", type: NgModelChangeDebouncedDirective, selector: "[stNgModelChangeDebounced]", outputs: ["stNgModelChangeDebounced"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: EditorColorPickerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'st-color-picker', template: "<button class=\"st-button st-toolbar-item\" [title]=\"button?.title || ''\" (stAction)=\"colorPicker.showPicker()\">\n  {{rgbStringToHex(state)}}\n  <input #colorPicker class=\"st-color-picker\" type=\"color\" [ngModel]=\"rgbStringToHex(state)\" tabindex=\"-1\"\n         (stNgModelChangeDebounced)=\"onCommand(button?.command, $event)\">\n  <i [class]=\"button?.icon\" [style.color]=\"state\"></i>\n</button>\n", styles: [".st-toolbar-item{border:0;padding:8px 14px;background-color:#fff;border-radius:5px;margin-right:1px;cursor:pointer}.st-toolbar-item:hover{background-color:#e0e0e0}.st-toolbar-item:focus{outline-color:#424242}.st-button:hover{background-color:#e0e0e0}.st-button:active{transform:scale(.98);box-shadow:1px 1px 7px 1px #e0e0e0}.st-button.active{background-color:#424242;color:#fff}.st-color-picker{width:0;height:0;border:0;padding:0;margin:0;pointer-events:none}\n"] }]
        }], propDecorators: { button: [{
                type: Input
            }], state: [{
                type: Input
            }], command: [{
                type: Output
            }] } });

const APPROX_WIDTH_THRESHOLD = 278;
const MARGIN_OFFSET = -150;
class EditorInputComponent {
    constructor(element, document) {
        this.element = element;
        this.document = document;
        this.command = new EventEmitter();
        this.showInputWindow = false;
        this.value = '';
        this.margin = 0; // workaround fox window width computing
        this.opacity = 0; // workaround fox window width computing
    }
    onCommand() {
        if (this.value) {
            if (this.selectionRange) {
                this.loadSelection();
            }
            this.closeInputWindow();
            this.command.emit({
                command: this.button.command,
                value: this.button.transform ? this.button.transform(this.value) : this.value
            });
            this.value = '';
        }
    }
    openInputWindow() {
        this.saveSelection();
        this.showInputWindow = true;
        setTimeout(() => {
            this.margin = this.windowElement.nativeElement.getBoundingClientRect().width < APPROX_WIDTH_THRESHOLD ? MARGIN_OFFSET : 0;
            this.opacity = 1;
            this.inputElement.nativeElement.focus();
        });
    }
    closeInputWindow() {
        this.showInputWindow = false;
        this.margin = 0;
        this.opacity = 0;
    }
    outsideClick($event) {
        if (!this.element.nativeElement.contains($event.target) && this.showInputWindow) {
            this.closeInputWindow();
        }
    }
    loadSelection() {
        const selection = this.document.defaultView.getSelection();
        selection.removeAllRanges();
        selection.addRange(this.selectionRange);
        this.selectionRange = null;
    }
    saveSelection() {
        const selection = this.document.defaultView.getSelection();
        this.selectionRange = selection.rangeCount === 0 ? null : selection.getRangeAt(0);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: EditorInputComponent, deps: [{ token: i0.ElementRef }, { token: DOCUMENT }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.2", type: EditorInputComponent, selector: "st-input", inputs: { button: "button", state: "state" }, outputs: { command: "command" }, host: { listeners: { "document:click": "outsideClick($event)" } }, viewQueries: [{ propertyName: "inputElement", first: true, predicate: ["input"], descendants: true }, { propertyName: "windowElement", first: true, predicate: ["window"], descendants: true }], ngImport: i0, template: "<st-button [button]=\"button\" [state]=\"state\" (command)=\"openInputWindow()\"></st-button>\n<div *ngIf=\"showInputWindow\" #window class=\"st-input-window\" (keyup.escape)=\"closeInputWindow()\" [style.margin-left.px]=\"margin\" [style.opacity]=\"opacity\" tabindex=\"0\">\n  <label *ngIf=\"button?.label\" class=\"st-input-label\" [for]=\"button?.label\">{{button?.label}}</label>\n  <div>\n    <input #input class=\"st-input-input\" type=\"text\" [id]=\"button?.label\" [title]=\"button?.label\" [(ngModel)]=\"value\">\n    <button class=\"st-input-button\" (stAction)=\"onCommand()\">Confirm</button>\n  </div>\n</div>\n", styles: [".st-toolbar-item,.st-input-button{border:0;padding:8px 14px;background-color:#fff;border-radius:5px;margin-right:1px;cursor:pointer}.st-toolbar-item:hover,.st-input-button:hover{background-color:#e0e0e0}.st-toolbar-item:focus,.st-input-button:focus{outline-color:#424242}.st-input-window{display:flex;flex-direction:column;background-color:#fff;position:absolute;padding:10px;top:5px;border:1px solid #bdbdbd;border-radius:5px;box-shadow:0 3px 7px #bdbdbd}.st-input-input{padding:8px 14px;background-color:#fff;margin-right:-1px;border:1px solid #bdbdbd;border-bottom-left-radius:5px;border-top-left-radius:5px}.st-input-button{margin-right:0;border-bottom-left-radius:0;border-top-left-radius:0;border:1px solid #bdbdbd}.st-input-label{font-size:14px;font-weight:700}\n"], dependencies: [{ kind: "directive", type: i2$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: EditorButtonComponent, selector: "st-button", inputs: ["button", "state"], outputs: ["command"] }, { kind: "directive", type: ActionDirective, selector: "[stAction]", outputs: ["stAction"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: EditorInputComponent, decorators: [{
            type: Component,
            args: [{ selector: 'st-input', template: "<st-button [button]=\"button\" [state]=\"state\" (command)=\"openInputWindow()\"></st-button>\n<div *ngIf=\"showInputWindow\" #window class=\"st-input-window\" (keyup.escape)=\"closeInputWindow()\" [style.margin-left.px]=\"margin\" [style.opacity]=\"opacity\" tabindex=\"0\">\n  <label *ngIf=\"button?.label\" class=\"st-input-label\" [for]=\"button?.label\">{{button?.label}}</label>\n  <div>\n    <input #input class=\"st-input-input\" type=\"text\" [id]=\"button?.label\" [title]=\"button?.label\" [(ngModel)]=\"value\">\n    <button class=\"st-input-button\" (stAction)=\"onCommand()\">Confirm</button>\n  </div>\n</div>\n", styles: [".st-toolbar-item,.st-input-button{border:0;padding:8px 14px;background-color:#fff;border-radius:5px;margin-right:1px;cursor:pointer}.st-toolbar-item:hover,.st-input-button:hover{background-color:#e0e0e0}.st-toolbar-item:focus,.st-input-button:focus{outline-color:#424242}.st-input-window{display:flex;flex-direction:column;background-color:#fff;position:absolute;padding:10px;top:5px;border:1px solid #bdbdbd;border-radius:5px;box-shadow:0 3px 7px #bdbdbd}.st-input-input{padding:8px 14px;background-color:#fff;margin-right:-1px;border:1px solid #bdbdbd;border-bottom-left-radius:5px;border-top-left-radius:5px}.st-input-button{margin-right:0;border-bottom-left-radius:0;border-top-left-radius:0;border:1px solid #bdbdbd}.st-input-label{font-size:14px;font-weight:700}\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: Document, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }], propDecorators: { button: [{
                type: Input
            }], state: [{
                type: Input
            }], command: [{
                type: Output
            }], inputElement: [{
                type: ViewChild,
                args: ['input', { static: false }]
            }], windowElement: [{
                type: ViewChild,
                args: ['window', { static: false }]
            }], outsideClick: [{
                type: HostListener,
                args: ['document:click', ['$event']]
            }] } });

class EditorSelectComponent {
    constructor() {
        this.command = new EventEmitter();
    }
    ngOnInit() {
        if (!this.state && this.button.items.length) {
            this.state = this.button.items[0].value;
        }
    }
    onCommand(command, value) {
        this.command.emit({ command, value });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: EditorSelectComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.2", type: EditorSelectComponent, selector: "st-select", inputs: { button: "button", state: "state" }, outputs: { command: "command" }, ngImport: i0, template: "<select [ngModel]=\"state\" [title]=\"button?.title || ''\" (ngModelChange)=\"onCommand(button?.command, $event)\" class=\"st-select st-toolbar-item\">\n  <option *ngFor=\"let i of button?.items\" [value]=\"i.value\">{{i.label}}</option>\n</select>\n", styles: [".st-toolbar-item{border:0;padding:8px 14px;background-color:#fff;border-radius:5px;margin-right:1px;cursor:pointer}.st-toolbar-item:hover{background-color:#e0e0e0}.st-toolbar-item:focus{outline-color:#424242}option:checked{background-color:#424242;color:#fff}\n"], dependencies: [{ kind: "directive", type: i2$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i2.NgSelectOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i2.ɵNgSelectMultipleOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i2.SelectControlValueAccessor, selector: "select:not([multiple])[formControlName],select:not([multiple])[formControl],select:not([multiple])[ngModel]", inputs: ["compareWith"] }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: EditorSelectComponent, decorators: [{
            type: Component,
            args: [{ selector: 'st-select', template: "<select [ngModel]=\"state\" [title]=\"button?.title || ''\" (ngModelChange)=\"onCommand(button?.command, $event)\" class=\"st-select st-toolbar-item\">\n  <option *ngFor=\"let i of button?.items\" [value]=\"i.value\">{{i.label}}</option>\n</select>\n", styles: [".st-toolbar-item{border:0;padding:8px 14px;background-color:#fff;border-radius:5px;margin-right:1px;cursor:pointer}.st-toolbar-item:hover{background-color:#e0e0e0}.st-toolbar-item:focus{outline-color:#424242}option:checked{background-color:#424242;color:#fff}\n"] }]
        }], propDecorators: { button: [{
                type: Input
            }], state: [{
                type: Input
            }], command: [{
                type: Output
            }] } });

class EditorSeparatorComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: EditorSeparatorComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.2", type: EditorSeparatorComponent, selector: "st-separator", ngImport: i0, template: "<div class=\"st-divider\">&nbsp;</div>\n", styles: [".st-toolbar-item{border:0;padding:8px 14px;background-color:#fff;border-radius:5px;margin-right:1px;cursor:pointer}.st-toolbar-item:hover{background-color:#e0e0e0}.st-toolbar-item:focus{outline-color:#424242}.st-divider{border-right:1px solid #bdbdbd;margin:0 5px 0 0;height:25px}\n"] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: EditorSeparatorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'st-separator', template: "<div class=\"st-divider\">&nbsp;</div>\n", styles: [".st-toolbar-item{border:0;padding:8px 14px;background-color:#fff;border-radius:5px;margin-right:1px;cursor:pointer}.st-toolbar-item:hover{background-color:#e0e0e0}.st-toolbar-item:focus{outline-color:#424242}.st-divider{border-right:1px solid #bdbdbd;margin:0 5px 0 0;height:25px}\n"] }]
        }] });

const MUTATION_OBSERVER_CONFIG = {
    attributes: true,
    childList: true,
    subtree: true,
    characterData: true
};
class DomModifyDirective {
    constructor(element) {
        this.element = element;
        this.domModify = new EventEmitter();
    }
    ngOnInit() {
        this.observer = new MutationObserver(() => {
            this.domModify.emit();
        });
        this.observer.observe(this.element.nativeElement, MUTATION_OBSERVER_CONFIG);
    }
    ngOnDestroy() {
        this.observer.disconnect();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: DomModifyDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.3.2", type: DomModifyDirective, selector: "[stDomModify]", outputs: { domModify: "stDomModify" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: DomModifyDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[stDomModify]'
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { domModify: [{
                type: Output,
                args: ['stDomModify']
            }] } });

class SelectionChangeDirective {
    constructor(document, element) {
        this.document = document;
        this.element = element;
        this.selectionChange = new EventEmitter();
    }
    selectionchange() {
        if (this.document.activeElement === this.element.nativeElement) {
            this.selectionChange.emit();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: SelectionChangeDirective, deps: [{ token: DOCUMENT }, { token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.3.2", type: SelectionChangeDirective, selector: "[stSelectionChange]", outputs: { selectionChange: "stSelectionChange" }, host: { listeners: { "document:selectionchange": "selectionchange()" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: SelectionChangeDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[stSelectionChange]'
                }]
        }], ctorParameters: () => [{ type: Document, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }, { type: i0.ElementRef }], propDecorators: { selectionChange: [{
                type: Output,
                args: ['stSelectionChange']
            }], selectionchange: [{
                type: HostListener,
                args: ['document:selectionchange']
            }] } });

class EditorDropdownComponent {
    constructor() {
        this.label = '';
        this.command = new EventEmitter();
    }
    set button(val) {
        this.label = val.label;
        if (this.width) {
            this._button = val;
        }
        else {
            this._tempButton = val;
        }
    }
    get button() {
        return this._button;
    }
    ngAfterViewInit() {
        setTimeout(() => {
            this.width = this.selectElement.nativeElement.getBoundingClientRect().width;
            this._button = this._tempButton;
        });
    }
    onCommand({ value: label }) {
        const { command, value } = this.button.items.find(item => item.label === label);
        this.command.emit({ command, value });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: EditorDropdownComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.2", type: EditorDropdownComponent, selector: "st-dropdown", inputs: { button: "button" }, outputs: { command: "command" }, viewQueries: [{ propertyName: "selectElement", first: true, predicate: ["select"], descendants: true }], ngImport: i0, template: "<select #select [title]=\"button?.title || ''\" (change)=\"onCommand($event.target); select.value = ''\" class=\"st-select st-toolbar-item\" [style.width.px]=\"this.width\">\n  <option value=\"\" disabled selected hidden>{{label}}</option>\n  <option *ngFor=\"let i of button?.items\" [value]=\"i.label\">{{i.label}}</option>\n</select>\n", styles: [".st-toolbar-item{border:0;padding:8px 14px;background-color:#fff;border-radius:5px;margin-right:1px;cursor:pointer}.st-toolbar-item:hover{background-color:#e0e0e0}.st-toolbar-item:focus{outline-color:#424242}\n"], dependencies: [{ kind: "directive", type: i2$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i2.NgSelectOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i2.ɵNgSelectMultipleOption, selector: "option", inputs: ["ngValue", "value"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: EditorDropdownComponent, decorators: [{
            type: Component,
            args: [{ selector: 'st-dropdown', template: "<select #select [title]=\"button?.title || ''\" (change)=\"onCommand($event.target); select.value = ''\" class=\"st-select st-toolbar-item\" [style.width.px]=\"this.width\">\n  <option value=\"\" disabled selected hidden>{{label}}</option>\n  <option *ngFor=\"let i of button?.items\" [value]=\"i.label\">{{i.label}}</option>\n</select>\n", styles: [".st-toolbar-item{border:0;padding:8px 14px;background-color:#fff;border-radius:5px;margin-right:1px;cursor:pointer}.st-toolbar-item:hover{background-color:#e0e0e0}.st-toolbar-item:focus{outline-color:#424242}\n"] }]
        }], propDecorators: { selectElement: [{
                type: ViewChild,
                args: ['select']
            }], button: [{
                type: Input
            }], command: [{
                type: Output
            }] } });

const DEFAULT_CONFIG = {
    placeholder: '',
    buttons: ST_BUTTONS,
};
class EditorComponent {
    set config(val) {
        this._config = { ...DEFAULT_CONFIG, ...val };
    }
    get config() {
        return this._config;
    }
    constructor(commandService) {
        this.commandService = commandService;
        this._config = DEFAULT_CONFIG;
        this.content = '';
        this.toolbarItemType = ToolbarItemType;
        this.isDisabled = false;
        this.queryCommandState = {};
    }
    ngAfterViewInit() {
        this.updateContentEditable();
    }
    writeValue(val) {
        this.content = val;
        this.updateContentEditable();
    }
    registerOnChange(fn) {
        this.onChangeFn = fn;
    }
    registerOnTouched(fn) {
        this.onTouchedFn = fn;
    }
    setDisabledState(isDisabled) {
        this.isDisabled = isDisabled;
    }
    domModify() {
        if (this.contentEditable) {
            this.onChangeFn(this.contentEditable.nativeElement.innerHTML);
        }
    }
    execCommand(command, value) {
        this.contentEditable.nativeElement.focus();
        this.commandService.execCommand(command, value);
        this.fetchQueryCommandState();
    }
    fetchQueryCommandState() {
        this.queryCommandState = this.commandService.getQueryCommandState(this.config.buttons);
    }
    trackBy(_, item) {
        return item.type;
    }
    updateContentEditable() {
        if (this.contentEditable) {
            this.contentEditable.nativeElement.innerHTML = this.content;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: EditorComponent, deps: [{ token: CommandService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.2", type: EditorComponent, selector: "st-editor", inputs: { config: "config" }, providers: [
            { provide: NG_VALUE_ACCESSOR, useExisting: EditorComponent, multi: true },
            CommandService
        ], viewQueries: [{ propertyName: "contentEditable", first: true, predicate: ["contentEditable"], descendants: true }], ngImport: i0, template: "<div class=\"st-editor-container\" [class.disabled]=\"isDisabled\">\n  <div class=\"st-toolbar\" tabIndex=\"0\">\n    <ng-container *ngFor=\"let item of config.buttons; trackBy:trackBy\" [ngSwitch]=\"item.type\">\n      <st-separator *ngSwitchCase=\"toolbarItemType.Separator\"></st-separator>\n      <st-button *ngIf=\"item.type === toolbarItemType.Button\"\n                                 [button]=\"item\" [state]=\"queryCommandState[item.command]\"\n                                 (command)=\"execCommand($event)\">\n      </st-button>\n      <st-select *ngSwitchCase=\"toolbarItemType.Select\"\n                         [button]=\"item\" [state]=\"queryCommandState[item.command]\"\n                         (command)=\"execCommand($event.command, $event.value)\">\n      </st-select>\n      <st-color-picker *ngSwitchCase=\"toolbarItemType.Color\"\n                               [button]=\"item\" [state]=\"queryCommandState[item.command]\"\n                               (command)=\"execCommand($event.command, $event.value)\">\n      </st-color-picker>\n      <st-input *ngSwitchCase=\"toolbarItemType.Input\"\n                        [button]=\"item\"\n                        (command)=\"execCommand($event.command, $event.value)\">\n      </st-input>\n      <st-dropdown *ngSwitchCase=\"toolbarItemType.Dropdown\"\n                [button]=\"item\"\n                (command)=\"execCommand($event.command, $event.value)\">\n      </st-dropdown>\n    </ng-container>\n  </div>\n  <div #contentEditable class=\"st-area\"\n       [attr.data-placeholder]=\"config.placeholder\" [attr.contenteditable]=\"!isDisabled\"\n       (stDomModify)=\"domModify()\" (stSelectionChange)=\"fetchQueryCommandState()\" (blur)=\"onTouchedFn()\"></div>\n</div>\n", styles: [".st-toolbar-item{border:0;padding:8px 14px;background-color:#fff;border-radius:5px;margin-right:1px;cursor:pointer}.st-toolbar-item:hover{background-color:#e0e0e0}.st-toolbar-item:focus{outline-color:#424242}.st-editor-container{position:relative}.st-editor-container.disabled{pointer-events:none;opacity:.5}.st-area{resize:vertical;overflow:auto;border:1px solid #bdbdbd;border-top:0;border-bottom-left-radius:5px;border-bottom-right-radius:5px;min-height:200px;padding:5px;background-color:#fff}.st-area:focus{outline-color:#424242}.st-area:empty:not(:focus):before{content:attr(data-placeholder);color:#bdbdbd;pointer-events:none}.st-toolbar{border-top-right-radius:5px;border-top-left-radius:5px;display:flex;flex-wrap:wrap;align-items:center;border:1px solid #bdbdbd;padding:5px;background-color:#fff}.st-toolbar:focus{outline-color:#424242}\n"], dependencies: [{ kind: "directive", type: i2$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i2$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2$1.NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { kind: "directive", type: i2$1.NgSwitchCase, selector: "[ngSwitchCase]", inputs: ["ngSwitchCase"] }, { kind: "component", type: EditorButtonComponent, selector: "st-button", inputs: ["button", "state"], outputs: ["command"] }, { kind: "component", type: EditorColorPickerComponent, selector: "st-color-picker", inputs: ["button", "state"], outputs: ["command"] }, { kind: "component", type: EditorInputComponent, selector: "st-input", inputs: ["button", "state"], outputs: ["command"] }, { kind: "component", type: EditorSelectComponent, selector: "st-select", inputs: ["button", "state"], outputs: ["command"] }, { kind: "component", type: EditorSeparatorComponent, selector: "st-separator" }, { kind: "directive", type: DomModifyDirective, selector: "[stDomModify]", outputs: ["stDomModify"] }, { kind: "directive", type: SelectionChangeDirective, selector: "[stSelectionChange]", outputs: ["stSelectionChange"] }, { kind: "component", type: EditorDropdownComponent, selector: "st-dropdown", inputs: ["button"], outputs: ["command"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: EditorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'st-editor', providers: [
                        { provide: NG_VALUE_ACCESSOR, useExisting: EditorComponent, multi: true },
                        CommandService
                    ], template: "<div class=\"st-editor-container\" [class.disabled]=\"isDisabled\">\n  <div class=\"st-toolbar\" tabIndex=\"0\">\n    <ng-container *ngFor=\"let item of config.buttons; trackBy:trackBy\" [ngSwitch]=\"item.type\">\n      <st-separator *ngSwitchCase=\"toolbarItemType.Separator\"></st-separator>\n      <st-button *ngIf=\"item.type === toolbarItemType.Button\"\n                                 [button]=\"item\" [state]=\"queryCommandState[item.command]\"\n                                 (command)=\"execCommand($event)\">\n      </st-button>\n      <st-select *ngSwitchCase=\"toolbarItemType.Select\"\n                         [button]=\"item\" [state]=\"queryCommandState[item.command]\"\n                         (command)=\"execCommand($event.command, $event.value)\">\n      </st-select>\n      <st-color-picker *ngSwitchCase=\"toolbarItemType.Color\"\n                               [button]=\"item\" [state]=\"queryCommandState[item.command]\"\n                               (command)=\"execCommand($event.command, $event.value)\">\n      </st-color-picker>\n      <st-input *ngSwitchCase=\"toolbarItemType.Input\"\n                        [button]=\"item\"\n                        (command)=\"execCommand($event.command, $event.value)\">\n      </st-input>\n      <st-dropdown *ngSwitchCase=\"toolbarItemType.Dropdown\"\n                [button]=\"item\"\n                (command)=\"execCommand($event.command, $event.value)\">\n      </st-dropdown>\n    </ng-container>\n  </div>\n  <div #contentEditable class=\"st-area\"\n       [attr.data-placeholder]=\"config.placeholder\" [attr.contenteditable]=\"!isDisabled\"\n       (stDomModify)=\"domModify()\" (stSelectionChange)=\"fetchQueryCommandState()\" (blur)=\"onTouchedFn()\"></div>\n</div>\n", styles: [".st-toolbar-item{border:0;padding:8px 14px;background-color:#fff;border-radius:5px;margin-right:1px;cursor:pointer}.st-toolbar-item:hover{background-color:#e0e0e0}.st-toolbar-item:focus{outline-color:#424242}.st-editor-container{position:relative}.st-editor-container.disabled{pointer-events:none;opacity:.5}.st-area{resize:vertical;overflow:auto;border:1px solid #bdbdbd;border-top:0;border-bottom-left-radius:5px;border-bottom-right-radius:5px;min-height:200px;padding:5px;background-color:#fff}.st-area:focus{outline-color:#424242}.st-area:empty:not(:focus):before{content:attr(data-placeholder);color:#bdbdbd;pointer-events:none}.st-toolbar{border-top-right-radius:5px;border-top-left-radius:5px;display:flex;flex-wrap:wrap;align-items:center;border:1px solid #bdbdbd;padding:5px;background-color:#fff}.st-toolbar:focus{outline-color:#424242}\n"] }]
        }], ctorParameters: () => [{ type: CommandService }], propDecorators: { config: [{
                type: Input
            }], contentEditable: [{
                type: ViewChild,
                args: ['contentEditable']
            }] } });

class NgxSimpleTextEditorModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: NgxSimpleTextEditorModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.2", ngImport: i0, type: NgxSimpleTextEditorModule, declarations: [EditorComponent,
            EditorButtonComponent,
            EditorColorPickerComponent,
            EditorInputComponent,
            EditorSelectComponent,
            EditorSeparatorComponent,
            DomModifyDirective,
            SelectionChangeDirective,
            EditorDropdownComponent,
            ActionDirective,
            NgModelChangeDebouncedDirective], imports: [CommonModule,
            FormsModule,
            ReactiveFormsModule], exports: [EditorComponent,
            EditorButtonComponent,
            EditorColorPickerComponent,
            EditorInputComponent,
            EditorSelectComponent,
            EditorSeparatorComponent,
            EditorDropdownComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: NgxSimpleTextEditorModule, imports: [CommonModule,
            FormsModule,
            ReactiveFormsModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.2", ngImport: i0, type: NgxSimpleTextEditorModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        EditorComponent,
                        EditorButtonComponent,
                        EditorColorPickerComponent,
                        EditorInputComponent,
                        EditorSelectComponent,
                        EditorSeparatorComponent,
                        DomModifyDirective,
                        SelectionChangeDirective,
                        EditorDropdownComponent,
                        ActionDirective,
                        NgModelChangeDebouncedDirective,
                    ],
                    imports: [
                        CommonModule,
                        FormsModule,
                        ReactiveFormsModule,
                    ],
                    exports: [
                        EditorComponent,
                        EditorButtonComponent,
                        EditorColorPickerComponent,
                        EditorInputComponent,
                        EditorSelectComponent,
                        EditorSeparatorComponent,
                        EditorDropdownComponent,
                    ]
                }]
        }] });

/*
 * Public API Surface of ngx-simple-text-editor
 */

/**
 * Generated bundle index. Do not edit.
 */

export { BOLD_BUTTON, CUSTOM, EditorButtonComponent, EditorColorPickerComponent, EditorComponent, EditorDropdownComponent, EditorInputComponent, EditorSelectComponent, EditorSeparatorComponent, FONT_SIZE_SELECT, FORE_COLOR, IMAGE_INPUT, INDENT_BUTTON, ITALIC_BUTTON, JUSTIFY_CENTER_BUTTON, JUSTIFY_FULL_BUTTON, JUSTIFY_LEFT_BUTTON, JUSTIFY_RIGHT_BUTTON, LINK_INPUT, NgxSimpleTextEditorModule, ORDERED_LIST_BUTTON, OUTDENT_BUTTON, REDO_BUTTON, REMOVE_FORMAT_BUTTON, SEPARATOR, STRIKE_THROUGH_BUTTON, ST_BUTTONS, SUBSCRIPT_BUTTON, SUPERSCRIPT_BUTTON, ToolbarItemType, UNDERLINE_BUTTON, UNDO_BUTTON, UNLINK_BUTTON, UNORDERED_LIST_BUTTON };
//# sourceMappingURL=ngx-simple-text-editor.mjs.map
